"use strict";

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; /**
                                                                                                                                                                                                                                                                   * Copyright (c) 2017-present, Facebook, Inc.
                                                                                                                                                                                                                                                                   * All rights reserved.
                                                                                                                                                                                                                                                                   *
                                                                                                                                                                                                                                                                   * This source code is licensed under the BSD-style license found in the
                                                                                                                                                                                                                                                                   * LICENSE file in the root directory of this source tree. An additional grant
                                                                                                                                                                                                                                                                   * of patent rights can be found in the PATENTS file in the same directory.
                                                                                                                                                                                                                                                                   */

var _prepackNode = require("./prepack-node.js");

var _fs = require("fs");

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var args = Array.from(process.argv);
args.splice(0, 2);
var inputFilename = void 0;
var outputFilename = void 0;
var compatibility = void 0;
var mathRandomSeed = void 0;
var inputSourceMap = void 0;
var outputSourceMap = void 0;
var flags = {
  speculate: false,
  trace: false,
  debugNames: false,
  singlePass: false,
  logStatistics: false,
  logModules: false,
  delayUnsupportedRequires: false,
  internalDebug: false
};
while (args.length) {
  var arg = args[0];args.shift();
  if (!arg.startsWith("--")) {
    inputFilename = arg;
  } else {
    arg = arg.slice(2);
    switch (arg) {
      case "out":
        arg = args[0];args.shift();
        outputFilename = arg;
        break;
      case "compatibility":
        arg = args[0];args.shift();
        if (arg !== "jsc-600-1-4-17") {
          console.error("Unsupported compatibility: " + arg);
          process.exit(1);
        } else {
          compatibility = arg;
        }
        break;
      case "mathRandomSeed":
        mathRandomSeed = args[0];args.shift();
        break;
      case "srcmapIn":
        inputSourceMap = args[0];args.shift();
        break;
      case "srcmapOut":
        outputSourceMap = args[0];args.shift();
        break;
      case "help":
        console.log("Usage: prepack.js [ --out output.js ] [ --compatibility jsc ] [ --mathRandomSeed seedvalue ] [ --srcmapIn inputMap ] [ --srcmapOut outputMap ] [ --speculate ] [ --trace ] [ -- | input.js ] [ --singlePass ] [ --debugNames ]");
        break;
      default:
        if (arg in flags) {
          flags[arg] = true;
        } else {
          console.error("Unknown option: " + arg);
          process.exit(1);
        }
    }
  }
}

if (!inputFilename) {
  console.error("Missing input file.");
  process.exit(1);
} else {
  try {
    var serialized = (0, _prepackNode.prepackFileSync)(inputFilename, _extends({
      compatibility: compatibility,
      mathRandomSeed: mathRandomSeed,
      inputSourceMapFilename: inputSourceMap,
      sourceMaps: !!outputSourceMap
    }, flags));

    var code = serialized.code;

    if (code.length >= 1000 || outputFilename) {
      var filename = outputFilename || inputFilename + "-processed.js";
      console.log("Prepacked source code written to " + filename + ".");
      _fs2.default.writeFileSync(filename, code);
    }

    if (code.length <= 1000 && !outputFilename) {
      console.log("+++++++++++++++++ Prepacked source code");
      console.log(code);
      console.log("=================");
    }

    if (outputSourceMap) {
      _fs2.default.writeFileSync(outputSourceMap, serialized.map || "");
    }
  } catch (x) {
    if (x instanceof _prepackNode.InitializationError) {
      // Ignore InitializationError since they have already logged
      // their errors to the console, but exit with an error code.
      process.exit(1);
    }
    // For any other type of error, rethrow.
    throw x;
  }
}
//# sourceMappingURL=prepack-cli.js.map